@@ -2,7 +2,7 @@ EV.lnre.gigp <- function (obj, N=NA, ...)
 {
   if (! inherits(obj, "lnre.gigp")) stop("argument must be object of class 'lnre.gigp'")
   if (missing(N)) stop("argument 'N' is required for 'lnre.gigp' objects")
-  if (!(is.numeric(N) && N >= 0)) stop("argument 'N' must be non-negative integer")
+  if (!(is.numeric(N) && all(N >= 0))) stop("argument 'N' must be non-negative integer")
 
   gamma <- obj$param$gamma
   b <- obj$param$B                      # use original notation from Baayen (2001)
