@@ -13,7 +13,7 @@ zipfR.begin.plot <- function (device=zipfR.par("device"), filename="",
   switch(device,
          x11 = X11(width=width, height=height, bg=bg, pointsize=pointsize),
          quartz = {quartz(width=width, height=height, pointsize=pointsize); par(bg=bg)},
-         png = png(file=paste(filename, "png", sep="."),
+         png = png(filename=paste(filename, "png", sep="."),
            width=width*png.res, height=height*png.res, res=png.res, bg=bg, pointsize=pointsize),
          eps = postscript(file=paste(filename, "eps", sep="."),
            width=width, height=height, bg=bg, pointsize=pointsize,
